"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("@angular/http");
require("rxjs/add/operator/toPromise");
var utils_1 = require("./utils");
var BaseService = /** @class */ (function () {
    function BaseService(http) {
        this.http = http;
        this.headers = new http_1.Headers({ 'Content-Type': 'application/json' });
        lastActiveTime = new Date();
    }
    /**
     * 分页查询
     * 参数：url URL地址, queryParam：用于查询的参数。waitLoading: 是否要显示等待加载
     * */
    BaseService.prototype.searchPage = function (url, queryParam, waitLoading) {
        var _this = this;
        if (waitLoading === void 0) { waitLoading = true; }
        if (waitLoading) {
            isRunning++;
        }
        if (!queryParam.pageNumber) {
            queryParam.pageNumber = 1;
        }
        if (!queryParam.pageSize) {
            queryParam.pageSize = 10;
        }
        if (url.indexOf("?") < 0) {
            url += "?x=1";
        }
        url += this.toUrl(queryParam, "");
        return this.http.get(url)
            .toPromise()
            .then(function (response) {
            if (waitLoading) {
                isRunning--;
            }
            lastActiveTime = new Date();
            var rst = response.json();
            _this.processDate(rst.datas);
            return rst;
        })
            .catch(function (err) { return _this.handleError(err, waitLoading); });
    };
    BaseService.prototype.toUrl = function (obj, propPrefix) {
        var url = "";
        var preParam = propPrefix;
        if (preParam) {
            preParam += ".";
        }
        if (obj == undefined) {
            return url;
        }
        if (typeof obj == 'object') {
            if (obj instanceof Array) {
                for (var i = 0; i < obj.length; i++) {
                    if (typeof (obj[i]) == 'object') {
                        url = url + this.toUrl(obj[i], propPrefix + "[" + i + "]");
                    }
                    else {
                        url = url + "&" + propPrefix + "[" + i + "]" + "=" + this.formatValue(obj[i]);
                    }
                }
            }
            else {
                for (var prop in obj) {
                    if (prop != "constructor") {
                        var pv = obj[prop];
                        if (pv) {
                            if (typeof pv == 'function')
                                continue;
                            if (typeof pv == 'object') {
                                url = url + this.toUrl(pv, preParam + prop);
                            }
                            else {
                                url = url + "&" + preParam + prop + "=" + this.formatValue(obj[prop]);
                            }
                        }
                    }
                }
            }
        }
        else {
            url = url + "&" + propPrefix + "=" + this.formatValue(obj);
        }
        return url;
    };
    BaseService.prototype.formatValue = function (val) {
        if (val instanceof Date) {
            return val.getTime();
        }
        return encodeURI(val);
    };
    /**
     * GET请求
     * 参数：url URL地址, data：用于查询的参数。waitLoading: 是否要显示等待加载
     * */
    BaseService.prototype.doGet = function (url, data, waitLoading) {
        var _this = this;
        if (waitLoading === void 0) { waitLoading = true; }
        if (data) {
            for (var prop in data) {
                if (prop != null && prop != undefined) {
                    if (url.indexOf("?") > 0) {
                        url = url + "&";
                    }
                    else {
                        url = url + "?";
                    }
                    url = url + prop + "=" + encodeURI(data[prop]);
                }
            }
        }
        if (waitLoading) {
            isRunning++;
        }
        return this.http.get(url)
            .toPromise()
            .then(function (response) {
            if (waitLoading) {
                isRunning--;
            }
            lastActiveTime = new Date();
            var rst = response.json();
            _this.processDate(rst);
            return rst;
        })
            .catch(function (err) { return _this.handleError(err, waitLoading); });
    };
    /**
     * PUT请求
     * 参数：url URL地址, data：参数。waitLoading: 是否要显示等待加载
     * */
    BaseService.prototype.doPut = function (url, data, waitLoading) {
        var _this = this;
        if (waitLoading === void 0) { waitLoading = true; }
        if (waitLoading) {
            isRunning++;
        }
        return this.http
            .put(url, data, { headers: this.headers })
            .toPromise()
            .then(function (response) {
            if (waitLoading) {
                isRunning--;
            }
            lastActiveTime = new Date();
            var rst = response.json();
            _this.processDate(rst);
            return rst;
        })
            .catch(function (err) { return _this.handleError(err, waitLoading); });
    };
    /**
     * POST请求
     * 参数：url URL地址, data：参数。waitLoading: 是否要显示等待加载
     * */
    BaseService.prototype.doPost = function (url, data, waitLoading) {
        var _this = this;
        if (waitLoading === void 0) { waitLoading = true; }
        if (waitLoading) {
            isRunning++;
        }
        return this.http
            .post(url, data, { headers: this.headers })
            .toPromise()
            .then(function (response) {
            if (waitLoading) {
                isRunning--;
            }
            lastActiveTime = new Date();
            var rst = response.json();
            _this.processDate(rst);
            return rst;
        })
            .catch(function (err) { return _this.handleError(err, waitLoading); });
    };
    /**
     * DELETE请求
     * 参数：url URL地址, data：参数。waitLoading: 是否要显示等待加载
     * */
    BaseService.prototype.doDelete = function (url, waitLoading) {
        var _this = this;
        if (waitLoading === void 0) { waitLoading = true; }
        if (waitLoading) {
            isRunning++;
        }
        return this.http.delete(url, { headers: this.headers })
            .toPromise()
            .then(function (response) {
            if (waitLoading) {
                isRunning--;
            }
            lastActiveTime = new Date();
            var rst = response.json();
            _this.processDate(rst);
            return rst;
        })
            .catch(function (err) { return _this.handleError(err, waitLoading); });
    };
    BaseService.prototype.processDate = function (rst) {
        if (rst) {
            if (Array.isArray(rst)) {
                for (var _i = 0, rst_1 = rst; _i < rst_1.length; _i++) {
                    var r = rst_1[_i];
                    this.processDate(r);
                }
            }
            else {
                for (var p in rst) {
                    if (typeof (rst[p]) == "object") {
                        this.processDate(rst[p]);
                    }
                    else if (p.endsWith("Date") || p.endsWith("Time") || p.endsWith("Timestamp")) {
                        if (typeof (rst[p]) == "number") {
                            rst[p] = new Date(rst[p]);
                        }
                        else if (rst[p].length == 28 && rst[p].indexOf("T") == 10) { //"2017-11-29T12:18:54.921+0000"
                            rst[p] = new Date(rst[p]);
                        }
                    }
                }
            }
        }
    };
    BaseService.prototype.handleError = function (error, waitLoading) {
        //console.error('An error occurred:'+ error);
        if (waitLoading) {
            isRunning--;
        }
        lastActiveTime = new Date();
        var msg = utils_1.Utils.resolveJsonErrorMessage(error);
        return Promise.reject(msg);
    };
    return BaseService;
}());
exports.BaseService = BaseService;
//# sourceMappingURL=base.service.js.map